from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="LabelSetUpdate")


@attr.s(auto_attribs=True)
class LabelSetUpdate:
    """
    Attributes:
        exclusive_classes (Union[Unset, bool]):
        label (Union[Unset, str]):
        nature (Union[Unset, str]):
    """

    exclusive_classes: Union[Unset, bool] = UNSET
    label: Union[Unset, str] = UNSET
    nature: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        exclusive_classes = self.exclusive_classes
        label = self.label
        nature = self.nature

        field_dict: Dict[str, Any] = {}
        field_dict.update({})
        if exclusive_classes is not UNSET:
            field_dict["exclusiveClasses"] = exclusive_classes
        if label is not UNSET:
            field_dict["label"] = label
        if nature is not UNSET:
            field_dict["nature"] = nature

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        exclusive_classes = d.pop("exclusiveClasses", UNSET)

        label = d.pop("label", UNSET)

        nature = d.pop("nature", UNSET)

        label_set_update = cls(
            exclusive_classes=exclusive_classes,
            label=label,
            nature=nature,
        )

        return label_set_update



from http import HTTPStatus
from typing import Any, Dict, Optional, Union, cast

import httpx

from ... import errors
from ...client import Client
from ...models.get_engine_parameters_schema_response_200 import GetEngineParametersSchemaResponse200
from ...types import UNSET, Response, Unset


def _get_kwargs(
    service: str,
    *,
    client: Client,
    nature: str,
    function: str,
    ui_schema: Union[Unset, None, bool] = False,
) -> Dict[str, Any]:
    url = "{}/services/{service}/parameters".format(client.base_url, service=service)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["nature"] = nature

    params["function"] = function

    params["uiSchema"] = ui_schema

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(
    *, client: Client, response: httpx.Response
) -> Optional[Union[Any, GetEngineParametersSchemaResponse200]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = GetEngineParametersSchemaResponse200.from_dict(response.json())

        return response_200
    if response.status_code == HTTPStatus.NOT_FOUND:
        response_404 = cast(Any, None)
        return response_404
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(
    *, client: Client, response: httpx.Response
) -> Response[Union[Any, GetEngineParametersSchemaResponse200]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    service: str,
    *,
    client: Client,
    nature: str,
    function: str,
    ui_schema: Union[Unset, None, bool] = False,
) -> Response[Union[Any, GetEngineParametersSchemaResponse200]]:
    """get the options of the given service in JSON schema format

    Args:
        service (str):
        nature (str):
        function (str):
        ui_schema (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, GetEngineParametersSchemaResponse200]]
    """

    kwargs = _get_kwargs(
        service=service,
        client=client,
        nature=nature,
        function=function,
        ui_schema=ui_schema,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    service: str,
    *,
    client: Client,
    nature: str,
    function: str,
    ui_schema: Union[Unset, None, bool] = False,
) -> Optional[Union[Any, GetEngineParametersSchemaResponse200]]:
    """get the options of the given service in JSON schema format

    Args:
        service (str):
        nature (str):
        function (str):
        ui_schema (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, GetEngineParametersSchemaResponse200]]
    """

    return sync_detailed(
        service=service,
        client=client,
        nature=nature,
        function=function,
        ui_schema=ui_schema,
    ).parsed


async def asyncio_detailed(
    service: str,
    *,
    client: Client,
    nature: str,
    function: str,
    ui_schema: Union[Unset, None, bool] = False,
) -> Response[Union[Any, GetEngineParametersSchemaResponse200]]:
    """get the options of the given service in JSON schema format

    Args:
        service (str):
        nature (str):
        function (str):
        ui_schema (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, GetEngineParametersSchemaResponse200]]
    """

    kwargs = _get_kwargs(
        service=service,
        client=client,
        nature=nature,
        function=function,
        ui_schema=ui_schema,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    service: str,
    *,
    client: Client,
    nature: str,
    function: str,
    ui_schema: Union[Unset, None, bool] = False,
) -> Optional[Union[Any, GetEngineParametersSchemaResponse200]]:
    """get the options of the given service in JSON schema format

    Args:
        service (str):
        nature (str):
        function (str):
        ui_schema (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[Union[Any, GetEngineParametersSchemaResponse200]]
    """

    return (
        await asyncio_detailed(
            service=service,
            client=client,
            nature=nature,
            function=function,
            ui_schema=ui_schema,
        )
    ).parsed



from typing import Any, Dict, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

T = TypeVar("T", bound="NewCampaignSession")


@attr.s(auto_attribs=True)
class NewCampaignSession:
    """
    Attributes:
        duration (int):
        label (str):
        split_size (float):
        reconciliation_username (Union[Unset, str]):
    """

    duration: int
    label: str
    split_size: float
    reconciliation_username: Union[Unset, str] = UNSET

    def to_dict(self) -> Dict[str, Any]:
        duration = self.duration
        label = self.label
        split_size = self.split_size
        reconciliation_username = self.reconciliation_username

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "duration": duration,
                "label": label,
                "splitSize": split_size,
            }
        )
        if reconciliation_username is not UNSET:
            field_dict["reconciliationUsername"] = reconciliation_username

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        duration = d.pop("duration")

        label = d.pop("label")

        split_size = d.pop("splitSize")

        reconciliation_username = d.pop("reconciliationUsername", UNSET)

        new_campaign_session = cls(
            duration=duration,
            label=label,
            split_size=split_size,
            reconciliation_username=reconciliation_username,
        )

        return new_campaign_session



from typing import Any, Dict, List, Type, TypeVar, cast

import attr

T = TypeVar("T", bound="CampaignUserGroup")


@attr.s(auto_attribs=True)
class CampaignUserGroup:
    """
    Attributes:
        label (str):
        users (List[str]):
    """

    label: str
    users: List[str]

    def to_dict(self) -> Dict[str, Any]:
        label = self.label
        users = self.users

        field_dict: Dict[str, Any] = {}
        field_dict.update(
            {
                "label": label,
                "users": users,
            }
        )

        return field_dict

    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        label = d.pop("label")

        users = cast(List[str], d.pop("users"))

        campaign_user_group = cls(
            label=label,
            users=users,
        )

        return campaign_user_group



from http import HTTPStatus
from typing import Any, Dict, List, Optional, Union

import httpx

from ... import errors
from ...client import Client
from ...models.lexicon import Lexicon
from ...types import UNSET, Response, Unset


def _get_kwargs(
    project_name: str,
    *,
    client: Client,
    compute_metrics: Union[Unset, None, bool] = False,
) -> Dict[str, Any]:
    url = "{}/projects/{projectName}/lexicons".format(client.base_url, projectName=project_name)

    headers: Dict[str, str] = client.get_headers()
    cookies: Dict[str, Any] = client.get_cookies()

    params: Dict[str, Any] = {}
    params["computeMetrics"] = compute_metrics

    params = {k: v for k, v in params.items() if v is not UNSET and v is not None}

    return {
        "method": "get",
        "url": url,
        "headers": headers,
        "cookies": cookies,
        "timeout": client.get_timeout(),
        "params": params,
    }


def _parse_response(*, client: Client, response: httpx.Response) -> Optional[List["Lexicon"]]:
    if response.status_code == HTTPStatus.OK:
        response_200 = []
        _response_200 = response.json()
        for componentsschemas_lexicon_array_item_data in _response_200:
            componentsschemas_lexicon_array_item = Lexicon.from_dict(componentsschemas_lexicon_array_item_data)

            response_200.append(componentsschemas_lexicon_array_item)

        return response_200
    if client.raise_on_unexpected_status:
        raise errors.UnexpectedStatus(f"Unexpected status code: {response.status_code}")
    else:
        return None


def _build_response(*, client: Client, response: httpx.Response) -> Response[List["Lexicon"]]:
    return Response(
        status_code=HTTPStatus(response.status_code),
        content=response.content,
        headers=response.headers,
        parsed=_parse_response(client=client, response=response),
    )


def sync_detailed(
    project_name: str,
    *,
    client: Client,
    compute_metrics: Union[Unset, None, bool] = False,
) -> Response[List["Lexicon"]]:
    """Get lexicons

    Args:
        project_name (str):
        compute_metrics (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['Lexicon']]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        compute_metrics=compute_metrics,
    )

    response = httpx.request(
        verify=client.verify_ssl,
        **kwargs,
    )

    return _build_response(client=client, response=response)


def sync(
    project_name: str,
    *,
    client: Client,
    compute_metrics: Union[Unset, None, bool] = False,
) -> Optional[List["Lexicon"]]:
    """Get lexicons

    Args:
        project_name (str):
        compute_metrics (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['Lexicon']]
    """

    return sync_detailed(
        project_name=project_name,
        client=client,
        compute_metrics=compute_metrics,
    ).parsed


async def asyncio_detailed(
    project_name: str,
    *,
    client: Client,
    compute_metrics: Union[Unset, None, bool] = False,
) -> Response[List["Lexicon"]]:
    """Get lexicons

    Args:
        project_name (str):
        compute_metrics (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['Lexicon']]
    """

    kwargs = _get_kwargs(
        project_name=project_name,
        client=client,
        compute_metrics=compute_metrics,
    )

    async with httpx.AsyncClient(verify=client.verify_ssl) as _client:
        response = await _client.request(**kwargs)

    return _build_response(client=client, response=response)


async def asyncio(
    project_name: str,
    *,
    client: Client,
    compute_metrics: Union[Unset, None, bool] = False,
) -> Optional[List["Lexicon"]]:
    """Get lexicons

    Args:
        project_name (str):
        compute_metrics (Union[Unset, None, bool]):

    Raises:
        errors.UnexpectedStatus: If the server returns an undocumented status code and Client.raise_on_unexpected_status is True.
        httpx.TimeoutException: If the request takes longer than Client.timeout.

    Returns:
        Response[List['Lexicon']]
    """

    return (
        await asyncio_detailed(
            project_name=project_name,
            client=client,
            compute_metrics=compute_metrics,
        )
    ).parsed
